@@ -1,5 +1,5 @@
 import textwrap
-from typing import List, Optional
+from typing import TYPE_CHECKING
 
 import pytest
 
@@ -7,8 +7,8 @@ from debputy.filesystem_scan import build_virtual_fs
 from debputy.lsp.config.config_options import DCO_SPELLCHECK_COMMENTS
 from debputy.lsp.languages.lsp_debian_control import _lint_debian_control
 from debputy.lsp.lsp_debian_control_reference_data import CURRENT_STANDARDS_VERSION
+from debputy.lsp.maint_prefs import MaintainerPreferenceTable
 from debputy.lsp.vendoring._deb822_repro import parse_deb822_file
-from debputy.lsprotocol.types import Diagnostic, DiagnosticSeverity
 from debputy.packages import DctrlParser
 from debputy.plugin.api import virtual_path_def
 from debputy.plugin.api.feature_set import PluginProvidedFeatureSet
@@ -17,9 +17,22 @@ from lint_tests.lint_tutil import (
     requires_levenshtein,
     LintWrapper,
     diag_range_to_text,
+    apply_code_action_edits,
+    standard_quick_fixes_for_diagnostic,
+    code_actions_for,
 )
 from tutil import build_time_only, with_plugins_loaded
 
+
+if TYPE_CHECKING:
+    from lsprotocol import types
+else:
+    from debputy.lsprotocol import types
+
+
+DiagnosticSeverity = types.DiagnosticSeverity
+
+
 ALL_REQUIRED_FILES = [
     "debian/changelog",
     "debian/copyright",
@@ -28,7 +41,7 @@ ALL_REQUIRED_FILES = [
 
 class DctrlLintWrapper(LintWrapper):
 
-    def __call__(self, lines: list[str]) -> list["Diagnostic"] | None:
+    def __call__(self, lines: list[str]) -> list[types.Diagnostic] | None:
         try:
             self.dctrl_lines = lines
             return super().__call__(lines)
@@ -2313,3 +2326,93 @@ def test_dctrl_lint_x_doc_main_package_valid(
     diagnostics = line_linter(lines)
     print(diagnostics)
     assert not diagnostics
+
+
+def test_dctrl_lint_maintainer_canonical_name(
+    line_linter: LintWrapper,
+) -> None:
+    styles = MaintainerPreferenceTable.load_preferences()
+    line_linter.maint_preference_table = styles
+    lines = textwrap.dedent(
+        f"""\
+    Source: foo
+    Standards-Version: {CURRENT_STANDARDS_VERSION}
+    Build-Depends: debhelper-compat (= 13)
+    Maintainer: Jane Developer <jane@example.com>
+    Uploaders: NT <niels@thykier.net>
+    Homepage: https://example.com
+
+    Package: foo-base
+    Architecture: all
+    Section: misc
+    X-Doc-Main-Package: foo
+    Description: some short synopsis
+     A very interesting description
+     with a valid synopsis
+     .
+     Just so be clear, this is for a test.
+
+    Package: foo
+    Architecture: all
+    Section: misc
+    Description: some short synopsis
+     A very interesting description
+     with a valid synopsis
+     .
+     Just so be clear, this is for a test.
+    """
+    ).splitlines(keepends=True)
+
+    diagnostics = line_linter(lines)
+    print(diagnostics)
+    assert len(diagnostics) == 1
+    issue = diagnostics[0]
+
+    msg = "Non-canonical or incorrect spelling of maintainer name"
+    assert issue.message == msg
+    assert f"{issue.range}" == "4:11-4:33"
+    assert issue.severity == DiagnosticSeverity.Information
+    assert diag_range_to_text(lines, issue.range) == "NT <niels@thykier.net>"
+    quick_fixes = standard_quick_fixes_for_diagnostic(
+        line_linter.lint_state,
+        code_actions_for(line_linter.lint_state.doc_uri, issue.range),
+        issue,
+    )
+    assert len(quick_fixes) == 1
+    quick_fix = quick_fixes[0]
+    assert isinstance(quick_fix, types.CodeAction)
+    fixed_text = apply_code_action_edits(
+        line_linter.lint_state.doc_uri,
+        lines,
+        quick_fix,
+    )
+
+    expected_text = textwrap.dedent(
+        f"""\
+    Source: foo
+    Standards-Version: {CURRENT_STANDARDS_VERSION}
+    Build-Depends: debhelper-compat (= 13)
+    Maintainer: Jane Developer <jane@example.com>
+    Uploaders: Niels Thykier <niels@thykier.net>
+    Homepage: https://example.com
+
+    Package: foo-base
+    Architecture: all
+    Section: misc
+    X-Doc-Main-Package: foo
+    Description: some short synopsis
+     A very interesting description
+     with a valid synopsis
+     .
+     Just so be clear, this is for a test.
+
+    Package: foo
+    Architecture: all
+    Section: misc
+    Description: some short synopsis
+     A very interesting description
+     with a valid synopsis
+     .
+     Just so be clear, this is for a test.
+    """
+    )
